@@ -364,19 +364,16 @@ extern const int INT123_costab_mmxsse[];
 #endif
 #endif
 
-/*
-	Now come two blocks of standard definitions for multi-decoder mode and single-decoder mode.
-	Most stuff is so automatic that it's indeed generated by some inline shell script.
-	Remember to use these scripts when possible, instead of direct repetitive hacking.
-*/
-
 #ifdef OPT_MULTI
 
 #	define defopt nodec
 
+#	ifndef NO_LAYER3
 #	if (defined OPT_3DNOW_VINTAGE || defined OPT_3DNOWEXT_VINTAGE || defined OPT_SSE || defined OPT_X86_64 || defined OPT_AVX || defined OPT_NEON || defined OPT_NEON64)
+#		define OPT_THE_DCT36
 #		define opt_dct36(fr) ((fr)->cpu_opts.the_dct36)
 #	endif
+#	endif
 
 #endif /* OPT_MULTI else */
 
